Module: Upton::Utils

Defined in:
lib/upton/utils.rb

Overview

This class contains a collection of helpers for Upton

Each method returns a Proc that (with an & ) can be used as the final argument to Upton's scrape and scrape_to_csv

Class Method Summary collapse